// *********************************************************************
//                             DEMO EXAMPLE
//                    RF receiver with authentication
// *********************************************************************
//
// Intended for:
//   HW: - TR-72G + CK-USB-04x development kit
//
//   OS: - v4.06G
//
// Description:
//   This example shows how to make a receiver with simple authentication.
//   - The transceiver permanently attempts to receive RF packets.
//   - If any packet is received:
//     - LED flashes once
//     - Received data is stored in buffer INFO.
//     - The acknowledge is sent and the receiver is waiting for confirmation.
//     - If confirmed the received data from buffer INFO is sent via SPI.
//       This can be displayed e.g. with the IQRF IDE Terminal.
//   Simple random generator can be replaced by a sophisticated
//   one by the user.
//
// ---------------------------------------------------------------------
// Online IQRF OS Reference Guide: https://doc.iqrf.org/IQRF-OS-Reference-guide
//
// Copyright (c) IQRF Tech s.r.o.
//
// File:    RX-AUTH.c
// Version: v3.00                                   Revision: 18/06/2021
//
// Revision history:
//   v3.00: 18/06/2021  First release for TR-7xG.
//
// *********************************************************************
// Default IQRF include (modify the path according to your setup)
#include "IQRF.h"

// *********************************************************************
uns8 randomValue_backup, dlen_backup;

// *********************************************************************
void APPLICATION()
{
    enableSPI();

    while (1)
    {
        toutRF = 50;
        randomValue_backup = randomValue; // Random value generated by IQRF OS

        if (RFRXpacket())
        {
            pulseLEDR();                // LED indication - message received
            dlen_backup = DLEN;
            copyBufferRF2INFO();        // Backup of received messsage
                                        // The message must be confirmed before
                                        //   sending via SPI

                                        // Send acknowledge:
                                        //  1B = 'A', 2B = random value x
            bufferRF[0] = 'A';
            bufferRF[1] = randomValue_backup;
            PIN = 0;
            DLEN = 2;
            waitMS(30);
            RFTXpacket();
            toutRF = 10;

            if (RFRXpacket())           // Wait for 2B of confirmation:
                                        //  1B = 'C', 2B = x ^ 0x5F
            {
                if ((DLEN == 2) && (bufferRF[0] == 'C'))
                {
                    if (bufferRF[1] == (randomValue_backup ^ 0x5F))
                    {                   // The message was confirmed
                        pulseLEDG();
                        copyBufferINFO2COM();
                        startSPI(dlen_backup);
                    }
                }
            }
        }
    }
}
// *********************************************************************
